detach method
DiContainer
detach()
Detaches and returns the current container without closing it.
Implementation
DiContainer detach() {
final DiContainer attached = container;
_container = null;
return attached;
}
Detaches and returns the current container without closing it.
DiContainer detach() {
final DiContainer attached = container;
_container = null;
return attached;
}