get<T> method
Resolves T synchronously from the current container hierarchy.
Async factories and async lazy singletons always require getAsync, even after their value has already been initialized.
Implementation
@override
T get<T>({final DiKey<T>? key}) => container.get<T>(key: key);