DiServiceLocatorAlreadyAttachedException class final

Thrown when a second container is attached without first detaching.

Inheritance

Constructors

DiServiceLocatorAlreadyAttachedException()
Creates an error for an attempted implicit container replacement.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable description of the failure.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited