DiServiceLocatorAlreadyAttachedException class final
Thrown when a second container is attached without first detaching.
- Inheritance
-
- Object
- DiServiceLocatorException
- DiServiceLocatorAlreadyAttachedException
Constructors
- DiServiceLocatorAlreadyAttachedException()
-
Creates an error for an attempted implicit container replacement.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited